@@ -6,7 +6,9 @@ def main():
     sys.exit(
             subprocess.call(['nosetests',
                     '-i',
-                    '^(it|ensure|must|should)',
+                    '^(it|ensure|must|should|specs?|examples?)',
+                    '-i',
+                    '(specs?(.py)?|examples?(.py)?)$',
                     '--with-spec',
                     '--spec-color',
                     ] + sys.argv[1:]))
